==> more_leaf_particles-1.0.0%2B1.21.8-sources.jar: net/fellter/moreLeafParticles/mixin/UntintedParticleLeavesBlockMixin.java <==
package net.fellter.moreLeafParticles.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.fellter.moreLeafParticles.ModParticles;
import net.fellter.moreLeafParticles.MoreLeafParticles;
import net.fellter.moreLeafParticles.yacl.YACLImpl;
import net.minecraft.class_10717;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2394;
import net.minecraft.class_2397;
import net.minecraft.class_5819;
import net.minecraft.class_5945;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_10717.class)
public abstract class UntintedParticleLeavesBlockMixin extends class_2397 {
	public UntintedParticleLeavesBlockMixin(float leafParticleChance, class_2251 settings) {
		super(leafParticleChance, settings);
	}

	@WrapOperation(method = "spawnLeafParticle", at = @At(value = "INVOKE", target = "Lnet/minecraft/particle/ParticleUtil;spawnParticle(Lnet/minecraft/world/World;Lnet/minecraft/util/math/BlockPos;Lnet/minecraft/util/math/random/Random;Lnet/minecraft/particle/ParticleEffect;)V"))
	private void fellter$spawnLeafParticle(class_1937 world, class_2338 pos, class_5819 random, class_2394 effect, Operation<Void> original) {
		if (MoreLeafParticles.isYACLPresent()) {
			class_2394 particle = YACLImpl.spawnParticleFromConfig(this);

			if (particle != null) {
				class_5945.method_49099(world, pos, random, particle);
			} else {
				original.call(world, pos, random, effect);
			}

			return;
		}

		if (this == class_2246.field_28673) {
			class_5945.method_49099(world, pos, random, ModParticles.AZALEA_LEAVES);
		} else if (this == class_2246.field_28674) {
			class_5945.method_49099(world, pos, random, ModParticles.FLOWERING_AZALEA_PARTICLES);
		} else {
			original.call(world, pos, random, effect);
		}
	}
}

==> more_leaf_particles-1.1.0%2B1.21.8-sources.jar: net/fellter/moreLeafParticles/mixin/UntintedParticleLeavesBlockMixin.java <==
package net.fellter.moreLeafParticles.mixin;

import com.llamalad7.mixinextras.injector.wrapoperation.Operation;
import com.llamalad7.mixinextras.injector.wrapoperation.WrapOperation;
import net.fellter.moreLeafParticles.ModParticles;
import net.fellter.moreLeafParticles.MoreLeafParticles;
import net.fellter.moreLeafParticles.yacl.ModConfig;
import net.minecraft.class_10717;
import net.minecraft.class_1937;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2394;
import net.minecraft.class_2397;
import net.minecraft.class_2398;
import net.minecraft.class_5819;
import net.minecraft.class_5945;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;

@Mixin(class_10717.class)
public abstract class UntintedParticleLeavesBlockMixin extends class_2397 {
	public UntintedParticleLeavesBlockMixin(float leafParticleChance, class_2251 settings) {
		super(leafParticleChance, settings);
	}

	@WrapOperation(method = "spawnLeafParticle", at = @At(value = "INVOKE", target = "Lnet/minecraft/particle/ParticleUtil;spawnParticle(Lnet/minecraft/world/World;Lnet/minecraft/util/math/BlockPos;Lnet/minecraft/util/math/random/Random;Lnet/minecraft/particle/ParticleEffect;)V"))
	private void fellter$spawnLeafParticle(class_1937 world, class_2338 pos, class_5819 random, class_2394 effect, Operation<Void> original) {
		if (MoreLeafParticles.isYACLPresent()) {
			if (this == class_2246.field_28673) {
				effect = ModConfig.enableAzalea ? ModParticles.AZALEA_LEAVES : null;
			} else if (this == class_2246.field_28674) {
				effect = ModConfig.enableFloweringAzalea ? ModParticles.FLOWERING_AZALEA_PARTICLES : null;
			} else if (this == class_2246.field_42731) {
				effect = ModConfig.enableCherry ? class_2398.field_43379 : null;
			} else if (this == class_2246.field_54714) {
				effect = ModConfig.enablePaleOak ? class_2398.field_55169 : null;
			}

			if (effect != null) {
				original.call(world, pos, random, effect);
			}

			return;
		}

		if (this == class_2246.field_28673) {
			class_5945.method_49099(world, pos, random, ModParticles.AZALEA_LEAVES);
		} else if (this == class_2246.field_28674) {
			class_5945.method_49099(world, pos, random, ModParticles.FLOWERING_AZALEA_PARTICLES);
		} else {
			original.call(world, pos, random, effect);
		}
	}
}
